Project Contributors
====================

The following people have made contributions to the project (in alphabetical
order) and are considered "The icepyx Developers".
Thanks goes to these wonderful people (`emoji key <https://allcontributors.org/docs/en/emoji-key>`_):

.. raw:: html

    <!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
    <!-- prettier-ignore-start -->
    <!-- markdownlint-disable -->
        <table>
      <tbody>
        <tr>
          <td align="center" valign="top" width="14.28%"><a href="https://nsidc.org"><img src="https://avatars.githubusercontent.com/u/47193922?v=4?s=100" width="100px;" alt="Amy Steiker"/><br /><sub><b>Amy Steiker</b></sub></a><br /><a href="#example-asteiker" title="Examples">💡</a> <a href="https://github.com/icesat2py/icepyx/commits?author=asteiker" title="Documentation">📖</a> <a href="#mentoring-asteiker" title="Mentoring">🧑‍🏫</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/annavalentine"><img src="https://avatars.githubusercontent.com/u/65192768?v=4?s=100" width="100px;" alt="Anna Valentine"/><br /><sub><b>Anna Valentine</b></sub></a><br /><a href="#example-annavalentine" title="Examples">💡</a></td>
          <td align="center" valign="top" width="14.28%"><a href="http://psc.apl.uw.edu/people/investigators/anthony-arendt/"><img src="https://avatars.githubusercontent.com/u/4993098?v=4?s=100" width="100px;" alt="Anthony Arendt"/><br /><sub><b>Anthony Arendt</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Aaaarendt" title="Bug reports">🐛</a> <a href="#business-aaarendt" title="Business development">💼</a> <a href="#eventOrganizing-aaarendt" title="Event Organizing">📋</a> <a href="#fundingFinding-aaarendt" title="Funding Finding">🔍</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/wallinb"><img src="https://avatars.githubusercontent.com/u/35819999?v=4?s=100" width="100px;" alt="Bruce Wallin"/><br /><sub><b>Bruce Wallin</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=wallinb" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/commits?author=wallinb" title="Documentation">📖</a> <a href="#ideas-wallinb" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Awallinb" title="Reviewed Pull Requests">👀</a> <a href="#question-wallinb" title="Answering Questions">💬</a></td>
          <td align="center" valign="top" width="14.28%"><a href="http://dshean.github.io"><img src="https://avatars.githubusercontent.com/u/1103530?v=4?s=100" width="100px;" alt="David Shean"/><br /><sub><b>David Shean</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Adshean" title="Bug reports">🐛</a> <a href="#mentoring-dshean" title="Mentoring">🧑‍🏫</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://www.linkedin.com/in/landungsetiawan/"><img src="https://avatars.githubusercontent.com/u/17802172?v=4?s=100" width="100px;" alt="Don Setiawan"/><br /><sub><b>Don Setiawan</b></sub></a><br /><a href="#infra-lsetiawan" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="#platform-lsetiawan" title="Packaging/porting to new platform">📦</a></td>
          <td align="center" valign="top" width="14.28%"><a href="http://facusapienza.com"><img src="https://avatars.githubusercontent.com/u/39526081?v=4?s=100" width="100px;" alt="Facundo Sapienza"/><br /><sub><b>Facundo Sapienza</b></sub></a><br /><a href="#example-facusapienza21" title="Examples">💡</a> <a href="https://github.com/icesat2py/icepyx/issues?q=author%3Afacusapienza21" title="Bug reports">🐛</a></td>
        </tr>
        <tr>
          <td align="center" valign="top" width="14.28%"><a href="http://fperez.org"><img src="https://avatars.githubusercontent.com/u/57394?v=4?s=100" width="100px;" alt="Fernando Perez"/><br /><sub><b>Fernando Perez</b></sub></a><br /><a href="#design-fperez" title="Design">🎨</a> <a href="#business-fperez" title="Business development">💼</a> <a href="#ideas-fperez" title="Ideas, Planning, & Feedback">🤔</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/jpswinski"><img src="https://avatars.githubusercontent.com/u/54070345?v=4?s=100" width="100px;" alt="JP Swinski"/><br /><sub><b>JP Swinski</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=jpswinski" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Ajpswinski" title="Reviewed Pull Requests">👀</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/JessicaS11"><img src="https://avatars.githubusercontent.com/u/11756442?v=4?s=100" width="100px;" alt="Jessica"/><br /><sub><b>Jessica</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3AJessicaS11" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=JessicaS11" title="Code">💻</a> <a href="#content-JessicaS11" title="Content">🖋</a> <a href="https://github.com/icesat2py/icepyx/commits?author=JessicaS11" title="Documentation">📖</a> <a href="#design-JessicaS11" title="Design">🎨</a> <a href="#example-JessicaS11" title="Examples">💡</a> <a href="#ideas-JessicaS11" title="Ideas, Planning, & Feedback">🤔</a> <a href="#maintenance-JessicaS11" title="Maintenance">🚧</a> <a href="#mentoring-JessicaS11" title="Mentoring">🧑‍🏫</a> <a href="#projectManagement-JessicaS11" title="Project Management">📆</a> <a href="#question-JessicaS11" title="Answering Questions">💬</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3AJessicaS11" title="Reviewed Pull Requests">👀</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/jomey"><img src="https://avatars.githubusercontent.com/u/178649?v=4?s=100" width="100px;" alt="Joachim Meyer"/><br /><sub><b>Joachim Meyer</b></sub></a><br /><a href="#mentoring-jomey" title="Mentoring">🧑‍🏫</a> <a href="#maintenance-jomey" title="Maintenance">🚧</a></td>
          <td align="center" valign="top" width="14.28%"><a href="http://bisson.work"><img src="https://avatars.githubusercontent.com/u/48059682?v=4?s=100" width="100px;" alt="Kelsey Bisson"/><br /><sub><b>Kelsey Bisson</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Akelseybisson" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=kelseybisson" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/commits?author=kelseybisson" title="Documentation">📖</a> <a href="#ideas-kelseybisson" title="Ideas, Planning, & Feedback">🤔</a> <a href="#example-kelseybisson" title="Examples">💡</a> <a href="#ideas-kelseybisson" title="Ideas, Planning, & Feedback">🤔</a> <a href="#mentoring-kelseybisson" title="Mentoring">🧑‍🏫</a> <a href="#question-kelseybisson" title="Answering Questions">💬</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Akelseybisson" title="Reviewed Pull Requests">👀</a> <a href="#tutorial-kelseybisson" title="Tutorials">✅</a></td>
          <td align="center" valign="top" width="14.28%"><a href="http://lindseyjh.ca/"><img src="https://avatars.githubusercontent.com/u/6361812?v=4?s=100" width="100px;" alt="Lindsey Heagy"/><br /><sub><b>Lindsey Heagy</b></sub></a><br /><a href="#mentoring-lheagy" title="Mentoring">🧑‍🏫</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Alheagy" title="Reviewed Pull Requests">👀</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/mollymwieringa"><img src="https://avatars.githubusercontent.com/u/40209354?v=4?s=100" width="100px;" alt="Molly Wieringa"/><br /><sub><b>Molly Wieringa</b></sub></a><br /><a href="#ideas-mollymwieringa" title="Ideas, Planning, & Feedback">🤔</a></td>
        </tr>
        <tr>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/nabib"><img src="https://avatars.githubusercontent.com/u/16991294?v=4?s=100" width="100px;" alt="Nicole Abib"/><br /><sub><b>Nicole Abib</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=nabib" title="Code">💻</a> <a href="#ideas-nabib" title="Ideas, Planning, & Feedback">🤔</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://rwegener2.github.io/"><img src="https://avatars.githubusercontent.com/u/35503632?v=4?s=100" width="100px;" alt="Rachel Wegener"/><br /><sub><b>Rachel Wegener</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Arwegener2" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=rwegener2" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/commits?author=rwegener2" title="Documentation">📖</a> <a href="#ideas-rwegener2" title="Ideas, Planning, & Feedback">🤔</a> <a href="#maintenance-rwegener2" title="Maintenance">🚧</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Arwegener2" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/icesat2py/icepyx/commits?author=rwegener2" title="Tests">⚠️</a> <a href="#tutorial-rwegener2" title="Tutorials">✅</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/norlandrhagen"><img src="https://avatars.githubusercontent.com/u/22455466?v=4?s=100" width="100px;" alt="Raphael Hagen"/><br /><sub><b>Raphael Hagen</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=norlandrhagen" title="Documentation">📖</a> <a href="#design-norlandrhagen" title="Design">🎨</a> <a href="https://github.com/icesat2py/icepyx/commits?author=norlandrhagen" title="Code">💻</a> <a href="#infra-norlandrhagen" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Anorlandrhagen" title="Reviewed Pull Requests">👀</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/RomiP"><img src="https://avatars.githubusercontent.com/u/17185856?v=4?s=100" width="100px;" alt="Romina Piunno"/><br /><sub><b>Romina Piunno</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=RomiP" title="Code">💻</a> <a href="#ideas-RomiP" title="Ideas, Planning, & Feedback">🤔</a> <a href="#mentoring-RomiP" title="Mentoring">🧑‍🏫</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3ARomiP" title="Reviewed Pull Requests">👀</a> <a href="#tutorial-RomiP" title="Tutorials">✅</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://www.linkedin.com/in/sarah-hall-902a9b150/"><img src="https://avatars.githubusercontent.com/u/51332703?v=4?s=100" width="100px;" alt="Sarah Hall"/><br /><sub><b>Sarah Hall</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Asjh1024" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=sjh1024" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/commits?author=sjh1024" title="Documentation">📖</a> <a href="#maintenance-sjh1024" title="Maintenance">🚧</a> <a href="https://github.com/icesat2py/icepyx/commits?author=sjh1024" title="Tests">⚠️</a></td>
          <td align="center" valign="top" width="14.28%"><a href="http://scottyhq.github.io"><img src="https://avatars.githubusercontent.com/u/3924836?v=4?s=100" width="100px;" alt="Scott Henderson"/><br /><sub><b>Scott Henderson</b></sub></a><br /><a href="#maintenance-scottyhq" title="Maintenance">🚧</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/salvis2"><img src="https://avatars.githubusercontent.com/u/27738742?v=4?s=100" width="100px;" alt="Sebastian Alvis"/><br /><sub><b>Sebastian Alvis</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=salvis2" title="Documentation">📖</a> <a href="#infra-salvis2" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a></td>
        </tr>
        <tr>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/ShashankBice"><img src="https://avatars.githubusercontent.com/u/29011666?v=4?s=100" width="100px;" alt="Shashank Bhushan"/><br /><sub><b>Shashank Bhushan</b></sub></a><br /><a href="#example-ShashankBice" title="Examples">💡</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://icetianli.github.io/"><img src="https://avatars.githubusercontent.com/u/45267156?v=4?s=100" width="100px;" alt="Tian Li"/><br /><sub><b>Tian Li</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Aicetianli" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=icetianli" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/commits?author=icetianli" title="Documentation">📖</a> <a href="#example-icetianli" title="Examples">💡</a> <a href="#ideas-icetianli" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Aicetianli" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/icesat2py/icepyx/commits?author=icetianli" title="Tests">⚠️</a> <a href="#tool-icetianli" title="Tools">🔧</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/loudTom"><img src="https://avatars.githubusercontent.com/u/33604148?v=4?s=100" width="100px;" alt="Tom Johnson"/><br /><sub><b>Tom Johnson</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=loudTom" title="Documentation">📖</a> <a href="#infra-loudTom" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://tsutterley.github.io/"><img src="https://avatars.githubusercontent.com/u/5384907?v=4?s=100" width="100px;" alt="Tyler Sutterley"/><br /><sub><b>Tyler Sutterley</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=tsutterley" title="Documentation">📖</a> <a href="https://github.com/icesat2py/icepyx/commits?author=tsutterley" title="Code">💻</a> <a href="#ideas-tsutterley" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-tsutterley" title="Answering Questions">💬</a> <a href="#security-tsutterley" title="Security">🛡️</a> <a href="https://github.com/icesat2py/icepyx/commits?author=tsutterley" title="Tests">⚠️</a></td>
          <td align="center" valign="top" width="14.28%"><a href="http://weiji14.github.io"><img src="https://avatars.githubusercontent.com/u/23487320?v=4?s=100" width="100px;" alt="Wei Ji"/><br /><sub><b>Wei Ji</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Aweiji14" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=weiji14" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/commits?author=weiji14" title="Documentation">📖</a> <a href="#example-weiji14" title="Examples">💡</a> <a href="#ideas-weiji14" title="Ideas, Planning, & Feedback">🤔</a> <a href="#infra-weiji14" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="#maintenance-weiji14" title="Maintenance">🚧</a> <a href="#mentoring-weiji14" title="Mentoring">🧑‍🏫</a> <a href="#question-weiji14" title="Answering Questions">💬</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Aweiji14" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/icesat2py/icepyx/commits?author=weiji14" title="Tests">⚠️</a> <a href="#talk-weiji14" title="Talks">📢</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://whyjz.github.io/"><img src="https://avatars.githubusercontent.com/u/19339926?v=4?s=100" width="100px;" alt="Whyjay Zheng"/><br /><sub><b>Whyjay Zheng</b></sub></a><br /><a href="#tutorial-whyjz" title="Tutorials">✅</a> <a href="https://github.com/icesat2py/icepyx/issues?q=author%3Awhyjz" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=whyjz" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Awhyjz" title="Reviewed Pull Requests">👀</a></td>
          <td align="center" valign="top" width="14.28%"><a href="http://wsauthoff.github.io"><img src="https://avatars.githubusercontent.com/u/63430469?v=4?s=100" width="100px;" alt="Wilson Sauthoff"/><br /><sub><b>Wilson Sauthoff</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Awsauthoff" title="Reviewed Pull Requests">👀</a></td>
        </tr>
        <tr>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/zachghiaccio"><img src="https://avatars.githubusercontent.com/u/48361714?v=4?s=100" width="100px;" alt="Zach Fair"/><br /><sub><b>Zach Fair</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Azachghiaccio" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=zachghiaccio" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/commits?author=zachghiaccio" title="Documentation">📖</a> <a href="#ideas-zachghiaccio" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-zachghiaccio" title="Answering Questions">💬</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Azachghiaccio" title="Reviewed Pull Requests">👀</a> <a href="#tutorial-zachghiaccio" title="Tutorials">✅</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/alexdibella"><img src="https://avatars.githubusercontent.com/u/66279468?v=4?s=100" width="100px;" alt="alexdibella"/><br /><sub><b>alexdibella</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Aalexdibella" title="Bug reports">🐛</a> <a href="#ideas-alexdibella" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/icesat2py/icepyx/commits?author=alexdibella" title="Code">💻</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://byrd.osu.edu/"><img src="https://avatars.githubusercontent.com/u/6469101?v=4?s=100" width="100px;" alt="bidhya"/><br /><sub><b>bidhya</b></sub></a><br /><a href="#example-bidhya" title="Examples">💡</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://learn2phoenix.github.io"><img src="https://avatars.githubusercontent.com/u/74139166?v=4?s=100" width="100px;" alt="learn2phoenix"/><br /><sub><b>learn2phoenix</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=learn2phoenix" title="Code">💻</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/liuzheng-arctic"><img src="https://avatars.githubusercontent.com/u/51420076?v=4?s=100" width="100px;" alt="liuzheng-arctic"/><br /><sub><b>liuzheng-arctic</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=liuzheng-arctic" title="Documentation">📖</a> <a href="https://github.com/icesat2py/icepyx/issues?q=author%3Aliuzheng-arctic" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=liuzheng-arctic" title="Code">💻</a> <a href="#ideas-liuzheng-arctic" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Aliuzheng-arctic" title="Reviewed Pull Requests">👀</a> <a href="#tool-liuzheng-arctic" title="Tools">🔧</a> <a href="#example-liuzheng-arctic" title="Examples">💡</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/nitin-ravinder"><img src="https://avatars.githubusercontent.com/u/86551841?v=4?s=100" width="100px;" alt="nitin-ravinder"/><br /><sub><b>nitin-ravinder</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Anitin-ravinder" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Anitin-ravinder" title="Reviewed Pull Requests">👀</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/ravindraK08"><img src="https://avatars.githubusercontent.com/u/124502384?v=4?s=100" width="100px;" alt="ravindraK08"/><br /><sub><b>ravindraK08</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3AravindraK08" title="Reviewed Pull Requests">👀</a></td>
        </tr>
        <tr>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/rtilling"><img src="https://avatars.githubusercontent.com/u/52253385?v=4?s=100" width="100px;" alt="rtilling"/><br /><sub><b>rtilling</b></sub></a><br /><a href="#ideas-rtilling" title="Ideas, Planning, & Feedback">🤔</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/SmithB"><img src="https://avatars.githubusercontent.com/u/2279144?v=4?s=100" width="100px;" alt="smithb"/><br /><sub><b>smithb</b></sub></a><br /><a href="#ideas-smithb" title="Ideas, Planning, & Feedback">🤔</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/tedmaksym"><img src="https://avatars.githubusercontent.com/u/13255911?v=4?s=100" width="100px;" alt="tedmaksym"/><br /><sub><b>tedmaksym</b></sub></a><br /><a href="#ideas-tedmaksym" title="Ideas, Planning, & Feedback">🤔</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/trevorskaggs"><img src="https://avatars.githubusercontent.com/u/1276123?v=4?s=100" width="100px;" alt="trevorskaggs"/><br /><sub><b>trevorskaggs</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Atrevorskaggs" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=trevorskaggs" title="Code">💻</a></td>
          <td align="center" valign="top" width="14.28%"><a href="https://github.com/trey-stafford"><img src="https://avatars.githubusercontent.com/u/19692879?v=4?s=100" width="100px;" alt="trey-stafford"/><br /><sub><b>trey-stafford</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/commits?author=trey-stafford" title="Code">💻</a> <a href="#ideas-trey-stafford" title="Ideas, Planning, & Feedback">🤔</a> <a href="#maintenance-trey-stafford" title="Maintenance">🚧</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Atrey-stafford" title="Reviewed Pull Requests">👀</a> <a href="#question-trey-stafford" title="Answering Questions">💬</a></td>
        </tr>
      </tbody>
    </table>

    <!-- markdownlint-restore -->
    <!-- prettier-ignore-end -->

    <!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the `all-contributors <https://github.com/all-contributors/all-contributors>`_ specification. Contributions of any kind welcome!
